GenericTransformStartDetails class

GenericTransformStartDetails genericizes all used input down events into a single class. This allows us to use the same logic for all input events.

Properties

focalPoint → Offset
The global focal point of the pointers in contact with the screen.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited