GenericTransformUpdateDetails class

GenericTransformUpdateDetails genericizes all used input events into a single class. This allows us to use the same logic for all input events.

Not all properties are used for all input events. For example, the PointerMoveEvent does not have a scale property, so it will always be 1.0.

You can use kind to determine the input type.

Constructors

GenericTransformUpdateDetails({required Offset focalPoint, required Offset localFocalPoint, required double scale, required double rotation, required int pointerCount, required PointerDeviceKind kind, int? buttons})
GenericTransformUpdateDetails.fromPointerMove(PointerMoveEvent details)
factory
GenericTransformUpdateDetails.fromPointerScroll(PointerScrollEvent details, ScrollWheelBehavior scrollWheelBehavior, [double scrollWheelSensitivity = 1.0])
factory
GenericTransformUpdateDetails.fromPointerUpdate(PointerPanZoomUpdateEvent details)
factory
GenericTransformUpdateDetails.fromScaleUpdate(ScaleUpdateDetails details)
factory

Properties

buttons → int?
The buttons that were pressed when the pointer event occurred.
final
focalPoint → Offset
The global focal point of the pointers in contact with the screen.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → PointerDeviceKind
The kind of input device from which the update originated.
final
localFocalPoint → Offset
The local focal point of the pointers in contact with the screen.
final
pointerCount → int
The number of pointers involved in the event.
final
rotation → double
This is the rotation factor for the rotation event.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
This is the scale factor for the scale event.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited